Compute the critical value for the Poisson KBQD tests for Uniformity
Source:R/critical_value.R
poisson_CV.RdThis function computes the empirical critical value for the U-statistics for testing uniformity on the sphere based on the centered poisson kernel.
Details
For each replication, a sample of d-dimensional observations from the uniform
distribution on the Sphere are generated and the Poisson kernel-based
U-statistic is computed. After B iterations, the critical value is selected
as the Quantile of the empirical distribution of the computed test
statistics.