This function computes the critical value for two-sample kernel tests with centered Gaussian kernel using one of three methods: bootstrap, permutation, or subsampling.
Arguments
- B
the number of bootstrap/permutation/subsampling samples to generate.
- Quantile
the quantile of the bootstrap/permutation/subsampling distribution to use as the critical value.
- data_pool
a matrix containing the data to be used in the test.
- size_x
the number of rows in the
data_poolmatrix corresponding to group X.- size_y
the number of rows in the
data_poolmatrix corresponding to group Y.- h
the tuning parameter for the kernel test.
- method
the method to use for computing the critical value (one of "bootstrap", "permutation", or "subsampling").
- b
the subsampling block size (only used if
methodis "subsampling").- compute_variance
indicates if the nonparametric variance is computed. Default is TRUE.