Compute the row-wise log-sum-exp of a numeric matrix in a numerically stable way. This is used to evaluate \(\log \sum_k \exp(x_{ik})\) without overflow or underflow by subtracting the row maximum before exponentiation.
Compute the row-wise log-sum-exp of a numeric matrix in a numerically stable way. This is used to evaluate \(\log \sum_k \exp(x_{ik})\) without overflow or underflow by subtracting the row maximum before exponentiation.